@@ -4,56 +4,64 @@ import scipy.sparse
 
 
 def get_bag_of_words(data, min_length):
-
+    """
+    Creates the bag of words
+    """
     vect = [np.bincount(x[x != np.array(None)].astype('int'), minlength=min_length)
             for x in data if np.sum(x[x != np.array(None)]) != 0]
 
-
     vect = scipy.sparse.csr_matrix(vect)
     return vect
 
 
-def bert_embeddings_from_file(text_file, sbert_model_to_load):
+def bert_embeddings_from_file(text_file, sbert_model_to_load, batch_size=200):
+    """
+    Creates SBERT Embeddings from an input file
+    """
     model = SentenceTransformer(sbert_model_to_load)
-
     with open(text_file) as filino:
         train_text = list(map(lambda x: x, filino.readlines()))
 
-    return np.array(model.encode(train_text))
+    return np.array(model.encode(train_text, show_progress_bar=True, batch_size=batch_size))
 
 
-def bert_embeddings_from_list(texts, sbert_model_to_load):
+def bert_embeddings_from_list(texts, sbert_model_to_load, batch_size=200):
+    """
+    Creates SBERT Embeddings from a list
+    """
     model = SentenceTransformer(sbert_model_to_load)
-    return np.array(model.encode(texts))
+    return np.array(model.encode(texts, show_progress_bar=True, batch_size=batch_size))
 
 
 class TextHandler:
-
-    def __init__(self, file_name):
+    """
+    Class used to handle the text preparation and the BagOfWord
+    """
+    def __init__(self, file_name=None, sentences=None):
         self.file_name = file_name
+        self.sentences = sentences
         self.vocab_dict = {}
         self.vocab = []
         self.index_dd = None
         self.idx2token = None
         self.bow = None
 
-    def load_text_file(self):
-        """
-        Loads a text file
-        :param text_file:
-        :return:
-        """
-        with open(self.file_name, "r") as filino:
-            data = filino.readlines()
-        return data
-
     def prepare(self):
         indptr = [0]
         indices = []
         data = []
         vocabulary = {}
-        with open(self.file_name, "r") as filino:
-            docs = filino.readlines()
+
+        if self.sentences == None and self.file_name == None:
+            raise Exception("Sentences and file_names cannot both be none")
+
+        if self.sentences != None:
+            docs = self.sentences
+        elif self.file_name != None:
+            with open(self.file_name, "r") as filino:
+                docs = filino.readlines()
+        else:
+            raise Exception("One parameter between sentences and file_name should be selected")
 
         for d in docs:
             for term in d.split():
